Module: Aws::ConnectHealth

Defined in:
lib/aws-sdk-connecthealth/endpoint_parameters.rb,
lib/aws-sdk-connecthealth/plugins/endpoints.rb,
lib/aws-sdk-connecthealth/endpoint_provider.rb,
lib/aws-sdk-connecthealth/event_streams.rb,
lib/aws-sdk-connecthealth/async_client.rb,
lib/aws-sdk-connecthealth/client_api.rb,
lib/aws-sdk-connecthealth/endpoints.rb,
lib/aws-sdk-connecthealth/resource.rb,
lib/aws-sdk-connecthealth/waiters.rb,
lib/aws-sdk-connecthealth/errors.rb,
lib/aws-sdk-connecthealth/client.rb,
lib/aws-sdk-connecthealth/types.rb,
lib/aws-sdk-connecthealth.rb

Overview

This module provides support for Connect Health. This module is available in the ‘aws-sdk-connecthealth` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

connect_health = Aws::ConnectHealth::Client.new
resp = connect_health.activate_subscription(params)

See Client for more information.

# Async Client

The AsyncClient class provides one asynchronous method for each API operation. Operation methods each accept a hash of request parameters and return an async response. For streaming operations, you can signal input events and register output event callbacks before waiting on the response.

connect_health = Aws::ConnectHealth::AsyncClient.new
resp = connect_health.activate_subscription(
  # params and input stream
 ) do |output_stream|
  # register callbacks for events
end

See AsyncClient for more information.

# Errors

Errors returned from Connect Health are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::ConnectHealth::Errors::ServiceError
  # rescues all Connect Health API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, EventStreams, Plugins, Types, Waiters Classes: AsyncClient, Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.2.0'