Class: Aws::ConnectHealth::AsyncClient
- Inherits:
-
Seahorse::Client::AsyncBase
- Object
- Seahorse::Client::AsyncBase
- Aws::ConnectHealth::AsyncClient
- Includes:
- AsyncClientStubs
- Defined in:
- lib/aws-sdk-connecthealth/async_client.rb,
sig/async_client.rbs
Overview
An API async client for ConnectHealth. To construct an async client, you need to configure a :region and :credentials.
async_client = Aws::ConnectHealth::AsyncClient.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _StartMedicalScribeListeningSessionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#start_medical_scribe_listening_session(params = {}) ⇒ Types::StartMedicalScribeListeningSessionOutput
Starts a new Medical Scribe listening session for real-time audio transcription.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ AsyncClient
constructor
A new instance of AsyncClient.
Constructor Details
#initialize(options) ⇒ AsyncClient
Returns a new instance of AsyncClient.
403 404 405 406 407 408 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 403 def initialize(*args) unless Kernel.const_defined?("HTTP2") raise "Must include http/2 gem to use AsyncClient instances." end super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
642 643 644 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 642 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
645 646 647 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 645 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/async_client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 605 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectHealth') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, http_response: Seahorse::Client::Http::AsyncResponse.new, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connecthealth' context[:gem_version] = '1.8.0' Seahorse::Client::Request.new(handlers, context) end |
#start_medical_scribe_listening_session(params = {}) ⇒ Types::StartMedicalScribeListeningSessionOutput
Starts a new Medical Scribe listening session for real-time audio transcription
82 |
# File 'sig/async_client.rbs', line 82
def start_medical_scribe_listening_session: (
|