Class: Aws::ConnectHealth::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectHealth::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connecthealth/client.rb,
sig/client.rbs
Overview
An API client for ConnectHealth. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectHealth::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ActivateSubscriptionResponseSuccess, _CreateDomainResponseSuccess, _CreateSubscriptionResponseSuccess, _DeactivateSubscriptionResponseSuccess, _DeleteDomainResponseSuccess, _GetDomainResponseSuccess, _GetMedicalScribeListeningSessionResponseSuccess, _GetPatientInsightsJobResponseSuccess, _GetSubscriptionResponseSuccess, _ListDomainsResponseSuccess, _ListSubscriptionsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartPatientInsightsJobResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_subscription(params = {}) ⇒ Types::ActivateSubscriptionOutput
Activates a Subscription to enable billing for a user.
-
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates a new Domain for managing HealthAgent resources.
-
#create_subscription(params = {}) ⇒ Types::CreateSubscriptionOutput
Creates a new Subscription within a Domain for billing and user management.
-
#deactivate_subscription(params = {}) ⇒ Types::DeactivateSubscriptionOutput
Deactivates a Subscription to stop billing for a user.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Domain and all associated resources.
-
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Retrieves information about a Domain.
-
#get_medical_scribe_listening_session(params = {}) ⇒ Types::GetMedicalScribeListeningSessionOutput
Retrieves details about an existing Medical Scribe listening session.
-
#get_patient_insights_job(params = {}) ⇒ Types::GetPatientInsightsJobResponse
Get details of a started patient insights job.
-
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Retrieves information about a Subscription.
-
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Domains for a given account.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists all Subscriptions within a Domain.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the specified resource.
-
#start_patient_insights_job(params = {}) ⇒ Types::StartPatientInsightsJobResponse
Starts a new patient insights job.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags with the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1205 1206 1207 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1205 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1208 1209 1210 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1208 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#activate_subscription(params = {}) ⇒ Types::ActivateSubscriptionOutput
Activates a Subscription to enable billing for a user.
89 |
# File 'sig/client.rbs', line 89
def activate_subscription: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1178 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectHealth') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connecthealth' context[:gem_version] = '1.8.0' Seahorse::Client::Request.new(handlers, context) end |
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates a new Domain for managing HealthAgent resources.
108 |
# File 'sig/client.rbs', line 108
def create_domain: (
|
#create_subscription(params = {}) ⇒ Types::CreateSubscriptionOutput
Creates a new Subscription within a Domain for billing and user management.
132 |
# File 'sig/client.rbs', line 132
def create_subscription: (
|
#deactivate_subscription(params = {}) ⇒ Types::DeactivateSubscriptionOutput
Deactivates a Subscription to stop billing for a user.
142 |
# File 'sig/client.rbs', line 142
def deactivate_subscription: (
|
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Domain and all associated resources.
155 |
# File 'sig/client.rbs', line 155
def delete_domain: (
|
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Retrieves information about a Domain.
174 |
# File 'sig/client.rbs', line 174
def get_domain: (
|
#get_medical_scribe_listening_session(params = {}) ⇒ Types::GetMedicalScribeListeningSessionOutput
Retrieves details about an existing Medical Scribe listening session
184 |
# File 'sig/client.rbs', line 184
def get_medical_scribe_listening_session: (
|
#get_patient_insights_job(params = {}) ⇒ Types::GetPatientInsightsJobResponse
Get details of a started patient insights job.
208 |
# File 'sig/client.rbs', line 208
def get_patient_insights_job: (
|
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Retrieves information about a Subscription.
219 |
# File 'sig/client.rbs', line 219
def get_subscription: (
|
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Domains for a given account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
231 |
# File 'sig/client.rbs', line 231
def list_domains: (
|
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists all Subscriptions within a Domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
244 |
# File 'sig/client.rbs', line 244
def list_subscriptions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the specified resource
256 |
# File 'sig/client.rbs', line 256
def list_tags_for_resource: (
|
#start_patient_insights_job(params = {}) ⇒ Types::StartPatientInsightsJobResponse
Starts a new patient insights job.
268 |
# File 'sig/client.rbs', line 268
def start_patient_insights_job: (
|
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags with the specified resource
305 |
# File 'sig/client.rbs', line 305
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource
312 |
# File 'sig/client.rbs', line 312
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1198 1199 1200 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1198 def waiter_names [] end |