Class: Aws::ConnectHealth::Types::GetPatientInsightsJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectHealth::Types::GetPatientInsightsJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connecthealth/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
Date and time the patient insights job was submitted.
- #encounter_context ⇒ Types::PatientInsightsEncounterContext
- #input_data_config ⇒ Types::InputDataConfig
- #insights_context ⇒ Types::InsightsContext
- #insights_output ⇒ Types::InsightsOutput
- #job_arn ⇒ String
- #job_id ⇒ String
- #job_status ⇒ String
- #output_data_config ⇒ Types::OutputDataConfig
- #patient_context ⇒ Types::PatientInsightsPatientContext
-
#status_details ⇒ String
Contains information about the status of a job.
-
#updated_time ⇒ Time
Date and time the patient insights job was last updated.
- #user_context ⇒ Types::UserContext
Instance Attribute Details
#creation_time ⇒ Time
Date and time the patient insights job was submitted.
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#encounter_context ⇒ Types::PatientInsightsEncounterContext
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::InputDataConfig
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#insights_context ⇒ Types::InsightsContext
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#insights_output ⇒ Types::InsightsOutput
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::OutputDataConfig
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#patient_context ⇒ Types::PatientInsightsPatientContext
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ String
Contains information about the status of a job.
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#updated_time ⇒ Time
Date and time the patient insights job was last updated.
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |
#user_context ⇒ Types::UserContext
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 625 class GetPatientInsightsJobResponse < Struct.new( :job_id, :job_arn, :job_status, :creation_time, :updated_time, :insights_output, :status_details, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config) SENSITIVE = [] include Aws::Structure end |