Class: Aws::ConnectHealth::Types::MedicalScribeBinaryAudioEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectHealth::Types::MedicalScribeBinaryAudioEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connecthealth/types.rb
Overview
An event containing raw binary audio data for the Medical Scribe stream. The audio is sent as a raw binary payload rather than as a base64-encoded value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_chunk ⇒ String
The raw binary audio data chunk.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
Instance Attribute Details
#audio_chunk ⇒ String
The raw binary audio data chunk
885 886 887 888 889 890 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 885 class MedicalScribeBinaryAudioEvent < Struct.new( :audio_chunk, :event_type) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ Object
Returns the value of attribute event_type
885 886 887 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 885 def event_type @event_type end |