Class: Aws::ConnectHealth::Types::MedicalScribeConfigurationEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectHealth::Types::MedicalScribeConfigurationEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connecthealth/types.rb
Overview
An event containing configuration for the Medical Scribe session
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_definitions ⇒ Array<Types::MedicalScribeChannelDefinition>
Channel definitions for the audio stream.
-
#encounter_context ⇒ Types::EncounterContext
Context information about the clinical encounter.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#post_stream_action_settings ⇒ Types::MedicalScribePostStreamActionSettings
Settings for actions to perform after the stream ends.
Instance Attribute Details
#channel_definitions ⇒ Array<Types::MedicalScribeChannelDefinition>
Channel definitions for the audio stream
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 927 class MedicalScribeConfigurationEvent < Struct.new( :post_stream_action_settings, :channel_definitions, :encounter_context, :event_type) SENSITIVE = [] include Aws::Structure end |
#encounter_context ⇒ Types::EncounterContext
Context information about the clinical encounter
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 927 class MedicalScribeConfigurationEvent < Struct.new( :post_stream_action_settings, :channel_definitions, :encounter_context, :event_type) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ Object
Returns the value of attribute event_type
927 928 929 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 927 def event_type @event_type end |
#post_stream_action_settings ⇒ Types::MedicalScribePostStreamActionSettings
Settings for actions to perform after the stream ends
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 927 class MedicalScribeConfigurationEvent < Struct.new( :post_stream_action_settings, :channel_definitions, :encounter_context, :event_type) SENSITIVE = [] include Aws::Structure end |