Class: Aws::ConnectHealth::Types::NoteTemplateSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connecthealth/types.rb

Overview

Note:

NoteTemplateSettings is a union - when making an API calls you must set exactly one of the members.

Settings for the note template to use for clinical note generation

Direct Known Subclasses

CustomTemplate, ManagedTemplate, Unknown

Defined Under Namespace

Classes: CustomTemplate, ManagedTemplate, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_templateTypes::CustomTemplate



1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-connecthealth/types.rb', line 1141

class NoteTemplateSettings < Struct.new(
  :managed_template,
  :custom_template,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ManagedTemplate < NoteTemplateSettings; end
  class CustomTemplate < NoteTemplateSettings; end
  class Unknown < NoteTemplateSettings; end
end

#managed_templateTypes::ManagedTemplate



1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-connecthealth/types.rb', line 1141

class NoteTemplateSettings < Struct.new(
  :managed_template,
  :custom_template,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ManagedTemplate < NoteTemplateSettings; end
  class CustomTemplate < NoteTemplateSettings; end
  class Unknown < NoteTemplateSettings; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1141
1142
1143
# File 'lib/aws-sdk-connecthealth/types.rb', line 1141

def unknown
  @unknown
end