Class: Aws::ConnectHealth::Types::StartPatientInsightsJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectHealth::Types::StartPatientInsightsJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connecthealth/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
- #domain_id ⇒ String
- #encounter_context ⇒ Types::PatientInsightsEncounterContext
- #input_data_config ⇒ Types::InputDataConfig
- #insights_context ⇒ Types::InsightsContext
- #output_data_config ⇒ Types::OutputDataConfig
- #patient_context ⇒ Types::PatientInsightsPatientContext
- #user_context ⇒ Types::UserContext
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#encounter_context ⇒ Types::PatientInsightsEncounterContext
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::InputDataConfig
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#insights_context ⇒ Types::InsightsContext
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::OutputDataConfig
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#patient_context ⇒ Types::PatientInsightsPatientContext
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#user_context ⇒ Types::UserContext
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1373 class StartPatientInsightsJobRequest < Struct.new( :domain_id, :patient_context, :insights_context, :encounter_context, :user_context, :input_data_config, :output_data_config, :client_token) SENSITIVE = [] include Aws::Structure end |