Class: Aws::ConnectHealth::Types::StartPatientInsightsJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectHealth::Types::StartPatientInsightsJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connecthealth/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
Date and time the patient insights job was submitted.
- #job_arn ⇒ String
- #job_id ⇒ String
Instance Attribute Details
#creation_time ⇒ Time
Date and time the patient insights job was submitted.
1415 1416 1417 1418 1419 1420 1421 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1415 class StartPatientInsightsJobResponse < Struct.new( :job_arn, :job_id, :creation_time) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
1415 1416 1417 1418 1419 1420 1421 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1415 class StartPatientInsightsJobResponse < Struct.new( :job_arn, :job_id, :creation_time) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
1415 1416 1417 1418 1419 1420 1421 |
# File 'lib/aws-sdk-connecthealth/types.rb', line 1415 class StartPatientInsightsJobResponse < Struct.new( :job_arn, :job_id, :creation_time) SENSITIVE = [] include Aws::Structure end |