Class: Aws::ConnectHealth::AsyncClient
- Inherits:
-
Seahorse::Client::AsyncBase
- Object
- Seahorse::Client::AsyncBase
- Aws::ConnectHealth::AsyncClient
- Includes:
- AsyncClientStubs
- Defined in:
- lib/aws-sdk-connecthealth/async_client.rb
Overview
An API async client for ConnectHealth. To construct an async client, you need to configure a ‘:region` and `:credentials`.
async_client = Aws::ConnectHealth::AsyncClient.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#start_medical_scribe_listening_session(params = {}) ⇒ Types::StartMedicalScribeListeningSessionOutput
Starts a new Medical Scribe listening session for real-time audio transcription.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ AsyncClient
constructor
A new instance of AsyncClient.
Constructor Details
#initialize(options) ⇒ AsyncClient
Returns a new instance of AsyncClient.
405 406 407 408 409 410 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 405 def initialize(*args) unless Kernel.const_defined?("HTTP2") raise "Must include http/2 gem to use AsyncClient instances." end super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
641 642 643 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 641 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
644 645 646 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 644 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 604 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectHealth') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, http_response: Seahorse::Client::Http::AsyncResponse.new, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connecthealth' context[:gem_version] = '1.2.0' Seahorse::Client::Request.new(handlers, context) end |
#start_medical_scribe_listening_session(params = {}) ⇒ Types::StartMedicalScribeListeningSessionOutput
Starts a new Medical Scribe listening session for real-time audio transcription
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/aws-sdk-connecthealth/async_client.rb', line 575 def start_medical_scribe_listening_session(params = {}, = {}, &block) params = params.dup input_event_stream_handler = _event_stream_handler( :input, params.delete(:input_event_stream_handler), EventStreams::MedicalScribeInputStream ) output_event_stream_handler = _event_stream_handler( :output, params.delete(:output_event_stream_handler) || params.delete(:event_stream_handler), EventStreams::MedicalScribeOutputStream ) yield(output_event_stream_handler) if block_given? req = build_request(:start_medical_scribe_listening_session, params) req.context[:input_event_stream_handler] = input_event_stream_handler req.handlers.add(Aws::Binary::EncodeHandler, priority: 55) req.context[:output_event_stream_handler] = output_event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 55) req.send_request(, &block) end |