Class: Aws::ConnectHealth::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectHealth::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connecthealth/client.rb
Overview
An API client for ConnectHealth. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectHealth::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_subscription(params = {}) ⇒ Types::ActivateSubscriptionOutput
Activates a Subscription to enable billing for a user.
-
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates a new Domain for managing HealthAgent resources.
-
#create_subscription(params = {}) ⇒ Types::CreateSubscriptionOutput
Creates a new Subscription within a Domain for billing and user management.
-
#deactivate_subscription(params = {}) ⇒ Types::DeactivateSubscriptionOutput
Deactivates a Subscription to stop billing for a user.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Domain and all associated resources.
-
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Retrieves information about a Domain.
-
#get_medical_scribe_listening_session(params = {}) ⇒ Types::GetMedicalScribeListeningSessionOutput
Retrieves details about an existing Medical Scribe listening session.
-
#get_patient_insights_job(params = {}) ⇒ Types::GetPatientInsightsJobResponse
Get details of a started patient insights job.
-
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Retrieves information about a Subscription.
-
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Domains for a given account.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists all Subscriptions within a Domain.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the specified resource.
-
#start_patient_insights_job(params = {}) ⇒ Types::StartPatientInsightsJobResponse
Starts a new patient insights job.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags with the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1205 1206 1207 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1205 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1208 1209 1210 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1208 def errors_module Errors end |
Instance Method Details
#activate_subscription(params = {}) ⇒ Types::ActivateSubscriptionOutput
Activates a Subscription to enable billing for a user.
522 523 524 525 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 522 def activate_subscription(params = {}, = {}) req = build_request(:activate_subscription, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1178 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectHealth') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connecthealth' context[:gem_version] = '1.5.0' Seahorse::Client::Request.new(handlers, context) end |
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates a new Domain for managing HealthAgent resources.
588 589 590 591 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 588 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_subscription(params = {}) ⇒ Types::CreateSubscriptionOutput
Creates a new Subscription within a Domain for billing and user management.
631 632 633 634 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 631 def create_subscription(params = {}, = {}) req = build_request(:create_subscription, params) req.send_request() end |
#deactivate_subscription(params = {}) ⇒ Types::DeactivateSubscriptionOutput
Deactivates a Subscription to stop billing for a user.
670 671 672 673 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 670 def deactivate_subscription(params = {}, = {}) req = build_request(:deactivate_subscription, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Domain and all associated resources.
702 703 704 705 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 702 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Retrieves information about a Domain.
752 753 754 755 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 752 def get_domain(params = {}, = {}) req = build_request(:get_domain, params) req.send_request() end |
#get_medical_scribe_listening_session(params = {}) ⇒ Types::GetMedicalScribeListeningSessionOutput
Retrieves details about an existing Medical Scribe listening session
812 813 814 815 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 812 def get_medical_scribe_listening_session(params = {}, = {}) req = build_request(:get_medical_scribe_listening_session, params) req.send_request() end |
#get_patient_insights_job(params = {}) ⇒ Types::GetPatientInsightsJobResponse
Get details of a started patient insights job.
873 874 875 876 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 873 def get_patient_insights_job(params = {}, = {}) req = build_request(:get_patient_insights_job, params) req.send_request() end |
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Retrieves information about a Subscription.
912 913 914 915 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 912 def get_subscription(params = {}, = {}) req = build_request(:get_subscription, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Domains for a given account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
957 958 959 960 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 957 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists all Subscriptions within a Domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1005 1006 1007 1008 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1005 def list_subscriptions(params = {}, = {}) req = build_request(:list_subscriptions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the specified resource
1034 1035 1036 1037 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1034 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_patient_insights_job(params = {}) ⇒ Types::StartPatientInsightsJobResponse
Starts a new patient insights job.
1115 1116 1117 1118 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1115 def start_patient_insights_job(params = {}, = {}) req = build_request(:start_patient_insights_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags with the specified resource
1143 1144 1145 1146 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1143 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource
1169 1170 1171 1172 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1169 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1198 1199 1200 |
# File 'lib/aws-sdk-connecthealth/client.rb', line 1198 def waiter_names [] end |