Class: Aws::ConnectHealth::Types::MedicalScribeInputStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-connecthealth/types.rb

Overview

Input stream for Medical Scribe containing audio and configuration events

EventStream is an Enumerator of Events.

#event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



1585
1586
1587
1588
1589
1590
1591
# File 'lib/aws-sdk-connecthealth/types.rb', line 1585

def event_types
  [
    :audio_event,
    :session_control_event,
    :configuration_event
  ]
end